Crate include_shader
source · [−]Expand description
A library to help working with shaders.
Although this library works on stable, your shader files changes might not be detected because
of caching. Therefore, until
track_path
API stabilizes, it is recommended to use the nightly toolchain and feature flag
so your shader files are tracked.
Optional features
nightly - Enables nightly APIs like
track_path
for shader files tracking.
Macros
Includes a shader file as a string with dependencies support.